# 🔐 Security Policy

## Supported Versions

We will address issues in the latest release. Older versions may not be supported.

| Version | Supported |
|---------|-----------|
| latest  | ✅        |
| older   | ❌        |

## Reporting Vulnerabilities

If you discover a security vulnerability, **please do not open an issue**.

Instead, contact the maintainers directly at [andreivataselu42@gmail.com](mailto:andreivataselu42@gmail.com), and we will respond promptly.

We appreciate responsible disclosure.